@@ -220,10 +220,10 @@ class GtkLanguageSelector(LanguageSelectorBase):
         if self.is_admin:
             # check if the package list is up-to-date
             if not self._cache.havePackageLists:
-                d = Gtk.MessageDialog(parent=self.window_main,
-                                      flags=Gtk.DialogFlags.MODAL,
-                                      message_type=Gtk.MessageType.INFO,
+                d = Gtk.MessageDialog(message_type=Gtk.MessageType.INFO,
                                       buttons=Gtk.ButtonsType.CANCEL)
+                d.set_modal(True)
+                d.set_transient_for(self.window_main)
                 d.set_markup("<big><b>%s</b></big>\n\n%s" % (
                     _("No language information available"),
                     _("The system does not have information about the "
@@ -448,8 +448,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
         currentIM = self.ImConfig.getCurrentInputMethod()
 
         # find out about the other options
-        names = dict(default=_('default'), xim=_('none'), ibus='IBus',
-          scim='SCIM', hangul='Hangul', thai='Thai')
+        names = dict(xim=_('none'), ibus='IBus', scim='SCIM', hangul='Hangul', thai='Thai')
         for (i, IM) in enumerate(self.ImConfig.getAvailableInputMethods()):
             name = names[IM] if IM in names else IM
             iter = model.append()
@@ -515,10 +514,10 @@ class GtkLanguageSelector(LanguageSelectorBase):
         return (to_inst, to_rm)
 
     def error(self, summary, msg):
-        d = Gtk.MessageDialog(parent=self.window_main,
-                              flags=Gtk.DialogFlags.MODAL,
-                              message_type=Gtk.MessageType.ERROR,
+        d = Gtk.MessageDialog(message_type=Gtk.MessageType.ERROR,
                               buttons=Gtk.ButtonsType.CLOSE)
+        d.set_modal(True)
+        d.set_transient_for(self.window_main)
         d.set_markup("<big><b>%s</b></big>\n\n%s" % (summary, msg))
         d.set_title=("")
         d.run()
@@ -586,7 +585,8 @@ class GtkLanguageSelector(LanguageSelectorBase):
 
     
     def _run_transaction(self, transaction):
-        dia = AptProgressDialog(transaction, parent=self.window_main)
+        dia = AptProgressDialog(transaction)
+        dia.set_transient_for(self.window_main)
         dia.connect("finished", self._on_finished)
         dia.run(error_handler=self._on_error)
         
@@ -659,9 +659,9 @@ class GtkLanguageSelector(LanguageSelectorBase):
         #print("Missing: %s " % missing)
         if len(missing) > 0:
             # FIXME: add "details"
-            d = Gtk.MessageDialog(parent=self.window_main,
-                                  flags=Gtk.DialogFlags.MODAL,
-                                  message_type=Gtk.MessageType.QUESTION)
+            d = Gtk.MessageDialog(message_type=Gtk.MessageType.QUESTION)
+            d.set_modal(True)
+            d.set_transient_for(self.window_main)
             d.set_markup("<big><b>%s</b></big>\n\n%s" % (
                 _("The language support is not installed completely"),
                 _("Some translations or writing aids available for your "
@@ -674,6 +674,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
             expander = Gtk.Expander.new(_("Details"))
             scroll = Gtk.ScrolledWindow()
             scroll.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+            scroll.set_min_content_height(130)
             textview = Gtk.TextView()
             textview.set_cursor_visible(False)
             textview.set_editable(False)
@@ -935,7 +936,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
                 "choice. The examples may show up if you\n"
                 "close and re-open Language Support.") % mylocale + ' ]')
             return
-        self.label_example_currency.set_text(locale.currency(20457.99))
+        self.label_example_currency.set_text(locale.currency(20457.99, grouping=True))
         self.label_example_number.set_text(locale.format("%.2f", 1234567.89, grouping=True))
         self.label_example_date.set_text(time.strftime(locale.nl_langinfo(locale.D_T_FMT)))
 
